==> gtk-gnutella_0.96.4.orig.tar.gz: gtk-gnutella-0.96.4/src/core/mime_types.h <==
MIME_TYPE(SHARE_M_APPLICATION_BINARY, 		"application/binary")
MIME_TYPE(SHARE_M_APPLICATION_BITTORRENT,	"application/x-bittorrent")
MIME_TYPE(SHARE_M_APPLICATION_BZIP2,  		"application/x-bzip2")
MIME_TYPE(SHARE_M_APPLICATION_DEB,		"application/x-debian-package")
MIME_TYPE(SHARE_M_APPLICATION_DMG,		"application/x-apple-diskimage")
MIME_TYPE(SHARE_M_APPLICATION_DOSEXEC,		"application/x-dosexec")
MIME_TYPE(SHARE_M_APPLICATION_GZIP,		"application/x-gzip")
MIME_TYPE(SHARE_M_APPLICATION_JAVA,		"application/java")
MIME_TYPE(SHARE_M_APPLICATION_OGG,		"application/ogg")
MIME_TYPE(SHARE_M_APPLICATION_PDF,		"application/pdf")
MIME_TYPE(SHARE_M_APPLICATION_POSTSCRIPT,	"application/postscript")
MIME_TYPE(SHARE_M_APPLICATION_RAR,		"application/rar")
MIME_TYPE(SHARE_M_APPLICATION_RDF,		"application/rss+rdf")
MIME_TYPE(SHARE_M_APPLICATION_RPM,		"application/x-redhat-package")
MIME_TYPE(SHARE_M_APPLICATION_RSS,		"application/rss+xml")
MIME_TYPE(SHARE_M_APPLICATION_SIT,		"application/stuffit")
MIME_TYPE(SHARE_M_APPLICATION_TAR,		"application/tar")
MIME_TYPE(SHARE_M_APPLICATION_ZIP,		"application/zip")
MIME_TYPE(SHARE_M_AUDIO_FLAC,			"audio/flac")
MIME_TYPE(SHARE_M_AUDIO_MATROSKA,		"audio/x-matroska")
MIME_TYPE(SHARE_M_AUDIO_MIDI,			"audio/midi")
MIME_TYPE(SHARE_M_AUDIO_MP4,			"audio/mp4")
MIME_TYPE(SHARE_M_AUDIO_MPEG,			"audio/mpeg")
MIME_TYPE(SHARE_M_AUDIO_MPEGURL,		"audio/x-mpegurl")
MIME_TYPE(SHARE_M_AUDIO_PLAYLIST,		"audio/x-scpls")
MIME_TYPE(SHARE_M_AUDIO_REALAUDIO,		"audio/x-realaudio")
MIME_TYPE(SHARE_M_AUDIO_WAVE,			"audio/x-wav")
MIME_TYPE(SHARE_M_IMAGE_BMP,			"image/bmp")
MIME_TYPE(SHARE_M_IMAGE_GIF,			"image/gif")
MIME_TYPE(SHARE_M_IMAGE_JPEG,			"image/jpeg")
MIME_TYPE(SHARE_M_IMAGE_PNG,			"image/png")
MIME_TYPE(SHARE_M_IMAGE_PSD,			"image/photoshop")
MIME_TYPE(SHARE_M_IMAGE_TIFF,			"image/tiff")
MIME_TYPE(SHARE_M_IMAGE_XPM,			"image/x-xpmi")
MIME_TYPE(SHARE_M_TEXT_C, 			"text/x-c")
MIME_TYPE(SHARE_M_TEXT_CPP, 			"text/x-c++")
MIME_TYPE(SHARE_M_TEXT_CSS, 			"text/css")
MIME_TYPE(SHARE_M_TEXT_HTML, 			"text/html")
MIME_TYPE(SHARE_M_TEXT_JAVA, 			"text/x-java")
MIME_TYPE(SHARE_M_TEXT_LATEX, 			"text/x-latex")
MIME_TYPE(SHARE_M_TEXT_PERL, 			"text/x-perl")
MIME_TYPE(SHARE_M_TEXT_PLAIN, 			"text/plain")
MIME_TYPE(SHARE_M_TEXT_RTF, 			"text/rtf")
MIME_TYPE(SHARE_M_TEXT_XHTML, 			"text/xhtml")
MIME_TYPE(SHARE_M_TEXT_XML, 			"text/xml")
MIME_TYPE(SHARE_M_VIDEO_FLV,			"video/x-flv")
MIME_TYPE(SHARE_M_VIDEO_MATROSKA,		"video/x-matroska")
MIME_TYPE(SHARE_M_VIDEO_MP4,			"video/mp4")
MIME_TYPE(SHARE_M_VIDEO_MPEG,			"video/mpeg")
MIME_TYPE(SHARE_M_VIDEO_MSVIDEO,		"video/x-msvideo")
MIME_TYPE(SHARE_M_VIDEO_OGM,			"video/x-ogg")
MIME_TYPE(SHARE_M_VIDEO_QUICKTIME,		"video/quicktime")

==> gtk-gnutella_0.96.5.orig.tar.gz: gtk-gnutella-0.96.5/src/core/mime_types.h <==
MIME_TYPE(SHARE_M_APPLICATION_BINARY, 		"application/binary")
MIME_TYPE(SHARE_M_APPLICATION_BITTORRENT,	"application/x-bittorrent")
MIME_TYPE(SHARE_M_APPLICATION_BZIP2,  		"application/x-bzip2")
MIME_TYPE(SHARE_M_APPLICATION_DEB,		"application/x-debian-package")
MIME_TYPE(SHARE_M_APPLICATION_DMG,		"application/x-apple-diskimage")
MIME_TYPE(SHARE_M_APPLICATION_DOSEXEC,		"application/x-dosexec")
MIME_TYPE(SHARE_M_APPLICATION_GZIP,		"application/x-gzip")
MIME_TYPE(SHARE_M_APPLICATION_JAVA,		"application/java")
MIME_TYPE(SHARE_M_APPLICATION_OGG,		"application/ogg")
MIME_TYPE(SHARE_M_APPLICATION_PDF,		"application/pdf")
MIME_TYPE(SHARE_M_APPLICATION_POSTSCRIPT,	"application/postscript")
MIME_TYPE(SHARE_M_APPLICATION_RAR,		"application/rar")
MIME_TYPE(SHARE_M_APPLICATION_RDF,		"application/rss+rdf")
MIME_TYPE(SHARE_M_APPLICATION_RPM,		"application/x-redhat-package")
MIME_TYPE(SHARE_M_APPLICATION_RSS,		"application/rss+xml")
MIME_TYPE(SHARE_M_APPLICATION_SIT,		"application/stuffit")
MIME_TYPE(SHARE_M_APPLICATION_TAR,		"application/tar")
MIME_TYPE(SHARE_M_APPLICATION_ZIP,		"application/zip")
MIME_TYPE(SHARE_M_AUDIO_FLAC,			"audio/flac")
MIME_TYPE(SHARE_M_AUDIO_MATROSKA,		"audio/x-matroska")
MIME_TYPE(SHARE_M_AUDIO_MIDI,			"audio/midi")
MIME_TYPE(SHARE_M_AUDIO_MP4,			"audio/mp4")
MIME_TYPE(SHARE_M_AUDIO_MPEG,			"audio/mpeg")
MIME_TYPE(SHARE_M_AUDIO_MPEGURL,		"audio/x-mpegurl")
MIME_TYPE(SHARE_M_AUDIO_OGG,			"audio/ogg")
MIME_TYPE(SHARE_M_AUDIO_PLAYLIST,		"audio/x-scpls")
MIME_TYPE(SHARE_M_AUDIO_REALAUDIO,		"audio/x-realaudio")
MIME_TYPE(SHARE_M_AUDIO_SPEEX,			"audio/x-speex")
MIME_TYPE(SHARE_M_AUDIO_WAVE,			"audio/x-wav")
MIME_TYPE(SHARE_M_IMAGE_BMP,			"image/bmp")
MIME_TYPE(SHARE_M_IMAGE_GIF,			"image/gif")
MIME_TYPE(SHARE_M_IMAGE_JPEG,			"image/jpeg")
MIME_TYPE(SHARE_M_IMAGE_PNG,			"image/png")
MIME_TYPE(SHARE_M_IMAGE_PSD,			"image/photoshop")
MIME_TYPE(SHARE_M_IMAGE_TIFF,			"image/tiff")
MIME_TYPE(SHARE_M_IMAGE_XPM,			"image/x-xpmi")
MIME_TYPE(SHARE_M_TEXT_C, 			"text/x-c")
MIME_TYPE(SHARE_M_TEXT_CPP, 			"text/x-c++")
MIME_TYPE(SHARE_M_TEXT_CSS, 			"text/css")
MIME_TYPE(SHARE_M_TEXT_HTML, 			"text/html")
MIME_TYPE(SHARE_M_TEXT_JAVA, 			"text/x-java")
MIME_TYPE(SHARE_M_TEXT_LATEX, 			"text/x-latex")
MIME_TYPE(SHARE_M_TEXT_PERL, 			"text/x-perl")
MIME_TYPE(SHARE_M_TEXT_PLAIN, 			"text/plain")
MIME_TYPE(SHARE_M_TEXT_RTF, 			"text/rtf")
MIME_TYPE(SHARE_M_TEXT_XHTML, 			"text/xhtml")
MIME_TYPE(SHARE_M_TEXT_XML, 			"text/xml")
MIME_TYPE(SHARE_M_VIDEO_FLV,			"video/x-flv")
MIME_TYPE(SHARE_M_VIDEO_MATROSKA,		"video/x-matroska")
MIME_TYPE(SHARE_M_VIDEO_MP4,			"video/mp4")
MIME_TYPE(SHARE_M_VIDEO_MPEG,			"video/mpeg")
MIME_TYPE(SHARE_M_VIDEO_MSVIDEO,		"video/x-msvideo")
MIME_TYPE(SHARE_M_VIDEO_OGG,			"video/ogg")
MIME_TYPE(SHARE_M_VIDEO_OGM,			"video/x-ogg")
MIME_TYPE(SHARE_M_VIDEO_QUICKTIME,		"video/quicktime")
